@@ -17,7 +17,5 @@ mod tests {
     #[test]
     fn test_key_gen() {
         gen_key();
-        std::fs::remove_file(".keys/privkey.pem").expect("Couldnt remove test keys");
-        std::fs::remove_dir(".keys").expect("Problem removing test keys directory");
     }
 }
