@@ -1,5 +1,4 @@
-use crate::blocks::block::*;
-use crate::blocks::chain::get_lmdb_connection;
+pub use crate::blocks::chain::*;
 use std::fs;
 use std::io::ErrorKind;
 
@@ -7,15 +6,6 @@ use std::io::ErrorKind;
 /// Creates a directory for the node to store data
 /// such as keys and logs
 ///
-/// # Examples
-/// ```
-/// use crate::daemon::daemon::create_node_file
-///
-/// fn main() {
-///     create_node_file();
-/// }
-/// ```
-///
 pub fn create_node_file() {
     // Create file for node
     match fs::create_dir("./.node") {
@@ -34,15 +24,6 @@ pub fn create_node_file() {
 /// Start a loop for main interface
 /// (Not an actual daemon)
 ///
-/// # Examples
-/// ```
-/// use crate::daemon::daemon::daemon_startup;
-///
-/// fn main() {
-///     let dproc = daemon_startup();
-/// }
-/// ```
-
 pub fn daemon_startup(bc_file: &'static str) -> std::io::Result<()> {
     let _bc_db = get_lmdb_connection(bc_file).unwrap();
     let mut bc = std::collections::HashMap::new();
